==> kpogre-1.2.7.tar.gz: kpogre-1.2.7/kpogre/Wizards/kpgtablecolumnwizinfo.h <==
//
// C++ Interface: kpgtablecolumnwizinfo
//
// Description: 
//
//
// Author: Lumir Vanek <lvanek@users.sourceforge.net>, (C) 2004
//
// Copyright: See COPYING file that comes with this distribution
//
//
#ifndef KPGTABLECOLUMNWIZINFO_H
#define KPGTABLECOLUMNWIZINFO_H

// include files for Qt
#include <qstring.h>
#include <qptrlist.h>

class QPixmap;

/**
Storage class for column info - name, base type, icon ... Used by create table wizard

@author Lumir Vanek
*/

class KPGTableColumnWizInfo
{
public:
	KPGTableColumnWizInfo() {;} 
   
	KPGTableColumnWizInfo(const QString &, const QString &, int, const QPixmap *);
	KPGTableColumnWizInfo(const KPGTableColumnWizInfo &);
				
	~KPGTableColumnWizInfo();
	
	void operator = (const KPGTableColumnWizInfo &src)
	{
			m_strName = src.name();
			m_strTypName = src.typName();
			m_pIcon = src.icon();
			m_nDimensions = src.nDimensions();
	}
	
	// Decide, if other column type is compatible for create foreign key
	bool isCompatible(const KPGTableColumnWizInfo &) const;

	// Return columns typname
	const QString & typName() const { return m_strTypName; }
		
	// Return name
	const QString & name() const { return m_strName; }
	
	// Return number of dimensions
	const int nDimensions() const { return m_nDimensions; }	
	
	// Return icon
	const QPixmap *icon() const { return m_pIcon; }	
	
protected:
	void convertTypNameToBase();
	
protected:
	QString m_strName;
	QString m_strTypName;
	int m_nDimensions;
	const QPixmap *m_pIcon;	
};


// Pointer list for KPGTableColumnWizInfo
class KPGListTableColumnWizInfo : public QPtrList<KPGTableColumnWizInfo>
{
	public:
		bool appendColumn(KPGTableColumnWizInfo *);
		void removeColumn(const QString &);
		KPGTableColumnWizInfo * findColumn(const QString &);
};

#endif

==> kpogre-1.5.2.tar.gz: kpogre-1.5.2/kpogre/Wizards/kpgtablecolumnwizinfo.h <==
//
// C++ Interface: kpgtablecolumnwizinfo
//
// Description: 
//
//
// Author: Lumir Vanek <lvanek@users.sourceforge.net>, (C) 2004
//
// Copyright: See COPYING file that comes with this distribution
//
//
#ifndef KPGTABLECOLUMNWIZINFO_H
#define KPGTABLECOLUMNWIZINFO_H

// include files for Qt
#include <qstring.h>
#include <qptrlist.h>
#include <qpixmap.h>


/**
Storage class for column info - name, base type, icon ... Used by create table wizard

@author Lumir Vanek
*/

class KPGTableColumnWizInfo
{
public:
	KPGTableColumnWizInfo() {;} 
   
	KPGTableColumnWizInfo(const QString &, const QString &, int, int, const QPixmap &);
	KPGTableColumnWizInfo(const KPGTableColumnWizInfo &);
				
	~KPGTableColumnWizInfo();
	
	void operator = (const KPGTableColumnWizInfo &src)
	{
		m_strName = src.name();
		m_strTypName = src.typName();
		m_Icon = src.icon();
		m_nDimensions = src.nDimensions();
	}
	
	// Decide, if other column type is compatible for create foreign key
	bool isCompatible(const KPGTableColumnWizInfo &) const;

	// Return columns typname
	const QString & typName() const { return m_strTypName; }
		
	// Return name
	const QString & name() const { return m_strName; }
	
	// Return number of dimensions
	const int nDimensions() const { return m_nDimensions; }	
	
	// Return column number in table
	int attNum() const { return m_iAttNum; }
	
	// Return icon
	const QPixmap & icon() const { return m_Icon; }	
	
protected:
	void convertTypNameToBase();
	
protected:
	QString m_strName;
	QString m_strTypName;
	int m_nDimensions;
	int m_iAttNum; 
	QPixmap m_Icon;	
};


// Pointer list for KPGTableColumnWizInfo
class KPGListTableColumnWizInfo : public QPtrList<KPGTableColumnWizInfo>
{
public:
	bool appendColumn(KPGTableColumnWizInfo *);
	void removeColumn(const QString &);
	KPGTableColumnWizInfo * findColumn(const QString &);
};

#endif
